==> jc-1.4.0.tar.gz: soot/tagkit/SourceLnPosTag.h <==
// public class soot.tagkit.SourceLnPosTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b45e923b919717d3 soot_tagkit_SourceLnPosTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_SourceLnPosTag_H_
#define _JC_soot_tagkit_SourceLnPosTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_SourceLnPosTag$sub_refs	_jc_soot_tagkit_SourceLnPosTag$sub_refs;
typedef struct _jc_soot_tagkit_SourceLnPosTag$sub_nonrefs	_jc_soot_tagkit_SourceLnPosTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_SourceLnPosTag$refs	_jc_soot_tagkit_SourceLnPosTag$refs;
typedef struct _jc_soot_tagkit_SourceLnPosTag$nonrefs	_jc_soot_tagkit_SourceLnPosTag$nonrefs;
typedef struct _jc_soot_tagkit_SourceLnPosTag$object	_jc_soot_tagkit_SourceLnPosTag$object;

typedef const struct _jc_soot_tagkit_SourceLnPosTag$vmethods	_jc_soot_tagkit_SourceLnPosTag$vmethods;
typedef const struct _jc_soot_tagkit_SourceLnPosTag$vtable	_jc_soot_tagkit_SourceLnPosTag$vtable;
typedef const struct _jc_soot_tagkit_SourceLnPosTag$vtype	_jc_soot_tagkit_SourceLnPosTag$vtype;

// Constructors
extern void _jc_soot_tagkit_SourceLnPosTag$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *, jint, jint, jint, jint);

// Virtual methods
extern jint _jc_soot_tagkit_SourceLnPosTag$method$endLn$7060419bb3b774bb(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *);
extern jint _jc_soot_tagkit_SourceLnPosTag$method$endPos$c193be7194a734ea(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourceLnPosTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *);
extern _jc_byte_array *_jc_soot_tagkit_SourceLnPosTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *);
extern jint _jc_soot_tagkit_SourceLnPosTag$method$startLn$ff07e45c2d38d239(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *);
extern jint _jc_soot_tagkit_SourceLnPosTag$method$startPos$8f6f52348ffc801a(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourceLnPosTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_SourceLnPosTag$method_info$endLn$7060419bb3b774bb;
extern _jc_method _jc_soot_tagkit_SourceLnPosTag$method_info$endPos$c193be7194a734ea;
extern _jc_method _jc_soot_tagkit_SourceLnPosTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_SourceLnPosTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_SourceLnPosTag$method_info$startLn$ff07e45c2d38d239;
extern _jc_method _jc_soot_tagkit_SourceLnPosTag$method_info$startPos$8f6f52348ffc801a;
extern _jc_method _jc_soot_tagkit_SourceLnPosTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_SourceLnPosTag$vmethods {
	jint	(*endLn$7060419bb3b774bb)(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *);
	jint	(*endPos$c193be7194a734ea)(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *);
	jint	(*startLn$ff07e45c2d38d239)(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *);
	jint	(*startPos$8f6f52348ffc801a)(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *);
};

// Vtable
struct _jc_soot_tagkit_SourceLnPosTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_SourceLnPosTag$vmethods	soot_tagkit_SourceLnPosTag;
};

// Vtype
struct _jc_soot_tagkit_SourceLnPosTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_SourceLnPosTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_SourceLnPosTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_SourceLnPosTag$refs {
    _jc_soot_tagkit_SourceLnPosTag$sub_refs	soot_tagkit_SourceLnPosTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_SourceLnPosTag$sub_nonrefs {
	jint	startLn;
	jint	endLn;
	jint	startPos;
	jint	endPos;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_SourceLnPosTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_SourceLnPosTag$sub_nonrefs	soot_tagkit_SourceLnPosTag;
};

// Object instance structure
struct _jc_soot_tagkit_SourceLnPosTag$object {
	_jc_soot_tagkit_SourceLnPosTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_SourceLnPosTag$vtype	*vtype;
	_jc_soot_tagkit_SourceLnPosTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_SourceLnPosTag$vtype _jc_soot_tagkit_SourceLnPosTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_SourceLnPosTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_SourceLnPosTag$class_object;

#endif	/* _JC_soot_tagkit_SourceLnPosTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/SourceLnPosTag.h <==
// public class soot.tagkit.SourceLnPosTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b45e923b919717d3 soot_tagkit_SourceLnPosTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_SourceLnPosTag_H_
#define _JC_soot_tagkit_SourceLnPosTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_SourceLnPosTag$sub_refs	_jc_soot_tagkit_SourceLnPosTag$sub_refs;
typedef struct _jc_soot_tagkit_SourceLnPosTag$sub_nonrefs	_jc_soot_tagkit_SourceLnPosTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_SourceLnPosTag$refs	_jc_soot_tagkit_SourceLnPosTag$refs;
typedef struct _jc_soot_tagkit_SourceLnPosTag$nonrefs	_jc_soot_tagkit_SourceLnPosTag$nonrefs;
typedef struct _jc_soot_tagkit_SourceLnPosTag$object	_jc_soot_tagkit_SourceLnPosTag$object;

typedef const struct _jc_soot_tagkit_SourceLnPosTag$vmethods	_jc_soot_tagkit_SourceLnPosTag$vmethods;
typedef const struct _jc_soot_tagkit_SourceLnPosTag$vtable	_jc_soot_tagkit_SourceLnPosTag$vtable;
typedef const struct _jc_soot_tagkit_SourceLnPosTag$vtype	_jc_soot_tagkit_SourceLnPosTag$vtype;

// Constructors
extern void _jc_soot_tagkit_SourceLnPosTag$method$_init$b5870f7bfece007a(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_tagkit_SourceLnPosTag$method$endLn$7060419bb3b774bb(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_tagkit_SourceLnPosTag$method$endPos$c193be7194a734ea(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourceLnPosTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_tagkit_SourceLnPosTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_tagkit_SourceLnPosTag$method$startLn$ff07e45c2d38d239(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_tagkit_SourceLnPosTag$method$startPos$8f6f52348ffc801a(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourceLnPosTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_SourceLnPosTag$method_info$endLn$7060419bb3b774bb;
extern _jc_method _jc_soot_tagkit_SourceLnPosTag$method_info$endPos$c193be7194a734ea;
extern _jc_method _jc_soot_tagkit_SourceLnPosTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_SourceLnPosTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_SourceLnPosTag$method_info$startLn$ff07e45c2d38d239;
extern _jc_method _jc_soot_tagkit_SourceLnPosTag$method_info$startPos$8f6f52348ffc801a;
extern _jc_method _jc_soot_tagkit_SourceLnPosTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_SourceLnPosTag$vmethods {
	jint	(*endLn$7060419bb3b774bb)(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *) _JC_JCNI_ATTR;
	jint	(*endPos$c193be7194a734ea)(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *) _JC_JCNI_ATTR;
	jint	(*startLn$ff07e45c2d38d239)(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *) _JC_JCNI_ATTR;
	jint	(*startPos$8f6f52348ffc801a)(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_SourceLnPosTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_SourceLnPosTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_SourceLnPosTag$vmethods	soot_tagkit_SourceLnPosTag;
};

// Vtype
struct _jc_soot_tagkit_SourceLnPosTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_SourceLnPosTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_SourceLnPosTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_SourceLnPosTag$refs {
    _jc_soot_tagkit_SourceLnPosTag$sub_refs	soot_tagkit_SourceLnPosTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_SourceLnPosTag$sub_nonrefs {
	jint	startLn;
	jint	endLn;
	jint	startPos;
	jint	endPos;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_SourceLnPosTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_SourceLnPosTag$sub_nonrefs	soot_tagkit_SourceLnPosTag;
};

// Object instance structure
struct _jc_soot_tagkit_SourceLnPosTag$object {
	_jc_soot_tagkit_SourceLnPosTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_SourceLnPosTag$vtype	*vtype;
	_jc_soot_tagkit_SourceLnPosTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_SourceLnPosTag$vtype _jc_soot_tagkit_SourceLnPosTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_SourceLnPosTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_SourceLnPosTag$class_object;

#endif	/* _JC_soot_tagkit_SourceLnPosTag_H_ */
